<?php
/**
 * Fichier gérant l'installation et désinstallation du plugin Contours.
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Fonction d'installation et de mise à jour du plugin.
 *
 * @param string $nom_meta_base_version Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 * @param string $version_cible         Version du schéma de données dans ce plugin (déclaré dans paquet.xml)
 *
 * @return void
**/
function contours_upgrade(string $nom_meta_base_version, string $version_cible) : void {
	$maj = [];

	include_spip('base/upgrade');
	maj_plugin($nom_meta_base_version, $version_cible, $maj);
}

/**
 * Fonction de désinstallation du plugin.
 *
 * @param string $nom_meta_base_version Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 *
 * @return void
**/
function contours_vider_tables(string $nom_meta_base_version) : void {
	// Effacer les points GIS et les liens associés en se limitant aux seuls territoires.
	// -- on boucle sur la liste des services géométrie plutôt que sur la liste des consignations qui est
	//    plus complexe à parcourir
	include_spip('inc/contour');
	include_spip('inc/contours_utils');
	$services = services_geometrie_acquerir();
	foreach ($services as $_service => $_configuration) {
		// On dépeuple le service, la fonction s'occupe elle-même de tester si cela est nécessaire.
		contour_depeupler($_configuration['tags']['type'], $_configuration['tags']['pays'], $_service);
	}

	// Effacer les meta du plugin
	effacer_meta('contours_peuplement');
	effacer_meta($nom_meta_base_version);
}
